%undefine __cmake_in_source_build

%define credential_modules_dir %{_libdir}/evolution-data-server/credential-modules
%define camel_provider_dir %{_libdir}/evolution-data-server/camel-providers
%define ebook_backends_dir %{_libdir}/evolution-data-server/addressbook-backends
%define ecal_backends_dir %{_libdir}/evolution-data-server/calendar-backends
%define modules_dir %{_libdir}/evolution-data-server/registry-modules
%define uimodules_dir %{_libdir}/evolution-data-server/ui-modules

%global dbus_service_name_address_book    org.gnome.evolution.dataserver.AddressBook10
%global dbus_service_name_calendar    org.gnome.evolution.dataserver.Calendar8
%global dbus_service_name_sources    org.gnome.evolution.dataserver.Sources5
%global dbus_service_name_user_prompter    org.gnome.evolution.dataserver.UserPrompter0

Summary: Backend data server for Evolution
Name:    evolution-data-server
Version: 3.49.1
Release: 7%{?dist}
License: LGPL-2.0-or-later
URL:     https://wiki.gnome.org/Apps/Evolution
Source0: http://download.gnome.org/sources/%{name}/3.46/%{name}-%{version}.tar.xz

BuildRequires: cmake gcc gcc-c++ gettext gperf ninja-build vala systemd openldap-devel krb5-devel
BuildRequires: pkgconfig(gio-2.0) pkgconfig(gio-unix-2.0) pkgconfig(gmodule-2.0) pkgconfig(icu-i18n)
BuildRequires: pkgconfig(goa-1.0) pkgconfig(gtk+-3.0) pkgconfig(gweather4) pkgconfig(libical-glib)
BuildRequires: pkgconfig(libsecret-unstable) pkgconfig(libsoup-3.0) pkgconfig(libxml-2.0)
BuildRequires: pkgconfig(nss) pkgconfig(nspr) pkgconfig(sqlite3) pkgconfig(webkit2gtk-4.1)
BuildRequires: pkgconfig(webkitgtk-6.0) pkgconfig(json-glib-1.0) pkgconfig(libcanberra-gtk3)

Requires: %{name}-langpacks = %{version}-%{release}
Provides: evolution-webcal = %{version}
Recommends: pinentry-gui

%description
The %{name} package provides a unified backend for programs that work with contacts, tasks, and calendar information.
It was originally developed for Evolution (hence the name), but is now used by other packages.

%package devel
Summary: Development files for building against %{name}
Requires: %{name} = %{version}-%{release}
Requires: pkgconfig(goa-1.0) pkgconfig(gweather4) pkgconfig(libical-glib) pkgconfig(libsecret-unstable)
Requires: pkgconfig(libsoup-3.0) pkgconfig(sqlite3) pkgconfig(webkit2gtk-4.1) pkgconfig(webkitgtk-6.0)
Requires: pkgconfig(json-glib-1.0)

%description devel
Development files needed for building things which link against %{name}.

%package langpacks
Summary: Translations for %{name}
BuildArch: noarch
Requires: %{name} = %{version}-%{release}

%description langpacks
This package contains translations for %{name}.

%package perl
Summary: Supplemental utilities that require Perl
Requires: %{name} = %{version}-%{release}
Requires: perl-interpreter

%description perl
This package contains supplemental utilities for %{name} that require Perl.

%package tests
Summary: Tests for the %{name} package
Requires: %{name} = %{version}-%{release}

%description tests
The %{name}-tests package contains tests that can be used to verify
the functionality of the installed %{name} package.

%prep
%autosetup -p1 -S gendiff

%build
%define ldap_flags -DWITH_OPENLDAP=ON
%define krb5_flags -DWITH_KRB5=ON
%define largefile_flags -DENABLE_LARGEFILE=ON
%define phonenum_flags -DWITH_PHONENUMBER=OFF
%define ssl_flags -DENABLE_SMIME=ON
%define gtkdoc_flags -DENABLE_GTK_DOC=OFF

if ! pkg-config --exists nss; then
  echo "Unable to find suitable version of nss to use!"
  exit 1
fi

export CPPFLAGS="-I%{_includedir}/et"
export CFLAGS="$RPM_OPT_FLAGS -DLDAP_DEPRECATED -fPIC -I%{_includedir}/et -Wno-deprecated-declarations"

%cmake -G Ninja \
    -DENABLE_MAINTAINER_MODE=OFF \
    -DENABLE_FILE_LOCKING=fcntl \
    -DENABLE_DOT_LOCKING=OFF \
    -DENABLE_INTROSPECTION=ON \
    -DENABLE_VALA_BINDINGS=ON \
    -DENABLE_INSTALLED_TESTS=ON \
    -DWITH_LIBDB=OFF \
    -DWITH_SYSTEMDUSERUNITDIR=%{_userunitdir} \
    %ldap_flags %krb5_flags %ssl_flags \
    %largefile_flags %gtkdoc_flags %phonenum_flags \
    %{nil}

%cmake_build

%install
%cmake_install

mkdir %{buildroot}/%{uimodules_dir} || :
mkdir %{buildroot}/%{credential_modules_dir} || :

find %{buildroot} -name '*.so.*' -exec chmod +x {} \;

%find_lang %{name}

%files
%license COPYING
%doc README ChangeLog NEWS
%{_libdir}/libcamel-1.2.so.64
%{_libdir}/libcamel-1.2.so.64.0.0
%{_libdir}/libebackend-1.2.so.11
%{_libdir}/libebackend-1.2.so.11.0.0
%{_libdir}/libebook-1.2.so.21
%{_libdir}/libebook-1.2.so.21.1.3
%{_libdir}/libebook-contacts-1.2.so.4
%{_libdir}/libebook-contacts-1.2.so.4.0.0
%{_libdir}/libecal-2.0.so.2
%{_libdir}/libecal-2.0.so.2.0.0
%{_libdir}/libedata-book-1.2.so.27
%{_libdir}/libedata-book-1.2.so.27.0.0
%{_libdir}/libedata-cal-2.0.so.2
%{_libdir}/libedata-cal-2.0.so.2.0.0
%{_libdir}/libedataserver-1.2.so.27
%{_libdir}/libedataserver-1.2.so.27.0.0
%{_libdir}/libedataserverui-1.2.so.4
%{_libdir}/libedataserverui-1.2.so.4.0.0
%{_libdir}/libedataserverui4-1.0.so.0
%{_libdir}/libedataserverui4-1.0.so.0.0.0
%{_libdir}/girepository-1.0/Camel-1.2.typelib
%{_libdir}/girepository-1.0/EBackend-1.2.typelib
%{_libdir}/girepository-1.0/EBook-1.2.typelib
%{_libdir}/girepository-1.0/EBookContacts-1.2.typelib
%{_libdir}/girepository-1.0/ECal-2.0.typelib
%{_libdir}/girepository-1.0/EDataBook-1.2.typelib
%{_libdir}/girepository-1.0/EDataCal-2.0.typelib
%{_libdir}/girepository-1.0/EDataServer-1.2.typelib
%{_libdir}/girepository-1.0/EDataServerUI-1.2.typelib
%{_libdir}/girepository-1.0/EDataServerUI4-1.0.typelib
%{_libexecdir}/camel-gpg-photo-saver
%{_libexecdir}/camel-index-control-1.2
%{_libexecdir}/camel-lock-helper-1.2
%{_libexecdir}/evolution-addressbook-factory
%{_libexecdir}/evolution-addressbook-factory-subprocess
%{_libexecdir}/evolution-calendar-factory
%{_libexecdir}/evolution-calendar-factory-subprocess
%{_libexecdir}/evolution-scan-gconf-tree-xml
%{_libexecdir}/evolution-source-registry
%{_libexecdir}/evolution-user-prompter
%dir %{_libexecdir}/evolution-data-server
%{_libexecdir}/evolution-data-server/addressbook-export
%{_libexecdir}/evolution-data-server/evolution-alarm-notify
%{_libexecdir}/evolution-data-server/list-sources

%{_sysconfdir}/xdg/autostart/org.gnome.Evolution-alarm-notify.desktop
%{_datadir}/applications/org.gnome.Evolution-alarm-notify.desktop
%{_datadir}/GConf/gsettings/evolution-data-server.convert
%{_datadir}/glib-2.0/schemas/org.gnome.Evolution.DefaultSources.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.evolution-data-server.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.evolution-data-server.addressbook.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.evolution-data-server.calendar.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.eds-shell.gschema.xml
%{_datadir}/glib-2.0/schemas/org.gnome.evolution.shell.network-config.gschema.xml
%{_datadir}/evolution-data-server
%{_datadir}/dbus-1/services/%{dbus_service_name_address_book}.service
%{_datadir}/dbus-1/services/%{dbus_service_name_calendar}.service
%{_datadir}/dbus-1/services/%{dbus_service_name_sources}.service
%{_datadir}/dbus-1/services/%{dbus_service_name_user_prompter}.service
%{_datadir}/pixmaps/evolution-data-server

%{_userunitdir}/evolution-addressbook-factory.service
%{_userunitdir}/evolution-calendar-factory.service
%{_userunitdir}/evolution-source-registry.service
%{_userunitdir}/evolution-user-prompter.service

%dir %{_libdir}/evolution-data-server
%dir %{credential_modules_dir}
%dir %{camel_provider_dir}
%dir %{ebook_backends_dir}
%dir %{ecal_backends_dir}
%dir %{modules_dir}
%dir %{uimodules_dir}

%{_libdir}/evolution-data-server/libedbus-private.so

%{camel_provider_dir}/libcamelimapx.so
%{camel_provider_dir}/libcamelimapx.urls
%{camel_provider_dir}/libcamellocal.so
%{camel_provider_dir}/libcamellocal.urls
%{camel_provider_dir}/libcamelnntp.so
%{camel_provider_dir}/libcamelnntp.urls
%{camel_provider_dir}/libcamelpop3.so
%{camel_provider_dir}/libcamelpop3.urls
%{camel_provider_dir}/libcamelsendmail.so
%{camel_provider_dir}/libcamelsendmail.urls
%{camel_provider_dir}/libcamelsmtp.so
%{camel_provider_dir}/libcamelsmtp.urls

%{credential_modules_dir}/module-credentials-goa.so
%{ebook_backends_dir}/libebookbackendcarddav.so
%{ebook_backends_dir}/libebookbackendfile.so
%{ebook_backends_dir}/libebookbackendldap.so
%{ecal_backends_dir}/libecalbackendcaldav.so
%{ecal_backends_dir}/libecalbackendcontacts.so
%{ecal_backends_dir}/libecalbackendfile.so
%{ecal_backends_dir}/libecalbackendgtasks.so
%{ecal_backends_dir}/libecalbackendhttp.so
%{ecal_backends_dir}/libecalbackendweather.so
%{ecal_backends_dir}/libecalbackendwebdavnotes.so
%{modules_dir}/module-cache-reaper.so
%{modules_dir}/module-google-backend.so
%{modules_dir}/module-gnome-online-accounts.so
%{modules_dir}/module-oauth2-services.so
%{modules_dir}/module-outlook-backend.so
%{modules_dir}/module-secret-monitor.so
%{modules_dir}/module-trust-prompt.so
%{modules_dir}/module-webdav-backend.so
%{modules_dir}/module-yahoo-backend.so

%files devel
%{_includedir}/evolution-data-server
%{_libdir}/libcamel-1.2.so
%{_libdir}/libebackend-1.2.so
%{_libdir}/libebook-1.2.so
%{_libdir}/libebook-contacts-1.2.so
%{_libdir}/libecal-2.0.so
%{_libdir}/libedata-book-1.2.so
%{_libdir}/libedata-cal-2.0.so
%{_libdir}/libedataserver-1.2.so
%{_libdir}/libedataserverui-1.2.so
%{_libdir}/libedataserverui4-1.0.so
%{_libdir}/pkgconfig/camel-1.2.pc
%{_libdir}/pkgconfig/evolution-data-server-1.2.pc
%{_libdir}/pkgconfig/libebackend-1.2.pc
%{_libdir}/pkgconfig/libebook-1.2.pc
%{_libdir}/pkgconfig/libebook-contacts-1.2.pc
%{_libdir}/pkgconfig/libecal-2.0.pc
%{_libdir}/pkgconfig/libedata-book-1.2.pc
%{_libdir}/pkgconfig/libedata-cal-2.0.pc
%{_libdir}/pkgconfig/libedataserver-1.2.pc
%{_libdir}/pkgconfig/libedataserverui-1.2.pc
%{_libdir}/pkgconfig/libedataserverui4-1.0.pc
%{_datadir}/gir-1.0/Camel-1.2.gir
%{_datadir}/gir-1.0/EBackend-1.2.gir
%{_datadir}/gir-1.0/EBook-1.2.gir
%{_datadir}/gir-1.0/EBookContacts-1.2.gir
%{_datadir}/gir-1.0/ECal-2.0.gir
%{_datadir}/gir-1.0/EDataBook-1.2.gir
%{_datadir}/gir-1.0/EDataCal-2.0.gir
%{_datadir}/gir-1.0/EDataServer-1.2.gir
%{_datadir}/gir-1.0/EDataServerUI-1.2.gir
%{_datadir}/gir-1.0/EDataServerUI4-1.0.gir
%{_datadir}/vala/vapi/camel-1.2.deps
%{_datadir}/vala/vapi/camel-1.2.vapi
%{_datadir}/vala/vapi/libebackend-1.2.deps
%{_datadir}/vala/vapi/libebackend-1.2.vapi
%{_datadir}/vala/vapi/libebook-1.2.deps
%{_datadir}/vala/vapi/libebook-1.2.vapi
%{_datadir}/vala/vapi/libebook-contacts-1.2.deps
%{_datadir}/vala/vapi/libebook-contacts-1.2.vapi
%{_datadir}/vala/vapi/libecal-2.0.deps
%{_datadir}/vala/vapi/libecal-2.0.vapi
%{_datadir}/vala/vapi/libedata-book-1.2.deps
%{_datadir}/vala/vapi/libedata-book-1.2.vapi
%{_datadir}/vala/vapi/libedata-cal-2.0.deps
%{_datadir}/vala/vapi/libedata-cal-2.0.vapi
%{_datadir}/vala/vapi/libedataserver-1.2.deps
%{_datadir}/vala/vapi/libedataserver-1.2.vapi
%{_datadir}/vala/vapi/libedataserverui-1.2.deps
%{_datadir}/vala/vapi/libedataserverui-1.2.vapi
%{_datadir}/vala/vapi/libedataserverui4-1.0.deps
%{_datadir}/vala/vapi/libedataserverui4-1.0.vapi

%files langpacks -f %{name}.lang

%files perl
%{_libexecdir}/evolution-data-server/csv2vcard

%files tests
%{_libdir}/libetestserverutils.so
%{_libdir}/libetestserverutils.so.0
%{_libdir}/libetestserverutils.so.0.0.0
%{_libexecdir}/%{name}/installed-tests
%{_datadir}/installed-tests

%changelog
* Mon Dec 23 2024 Rebuild Robot <rebot@opencloudos.org> - 3.49.1-7
- [Type] other
- [DESC] Rebuilt for icu

* Mon Oct 28 2024 Rebuild Robot <rebot@opencloudos.org> - 3.49.1-6
- [Type] bugfix
- [DESC] Rebuilt for nss

* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.49.1-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.49.1-4
- Rebuilt for loongarch release

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.49.1-3
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 rockerzhu <rockerzhu@tencent.com> - 3.49.1-2
- Rebuilt for icu 73.2

* Mon Jul 24 2023 Xiaojie Chen <jackxjchen@tencent.com> - 3.49.1-1
- Upgrade to upstream version 3.49.1 for webkitgtk 2.41.6

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.46.1-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.46.1-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 8 2022 Shuo Wang <abushwang@tencent.com> - 3.46.1-1
- initial build
